package com.example.pda.network

import android.util.Log
import com.example.pda.model.InventoryItem
import kotlinx.coroutines.CoroutineScope
import kotlinx.coroutines.Dispatchers
import kotlinx.coroutines.launch

// 网络请求助手对象，用于处理与服务器的交互
object NetworkHelper {
    private const val TAG = "NetworkHelper"

    // 提交库存数据到服务器的方法
    fun submitData(
        data: List<InventoryItem>, // 库存数据列表
        onSuccess: () -> Unit, // 提交成功后的回调函数
        onError: (String) -> Unit // 提交失败后的回调函数
    ) {
        // 在IO线程中启动协程以执行网络请求
        CoroutineScope(Dispatchers.IO).launch {
            try {
                // 调用RetrofitClient的submitInventory方法提交数据
                val response = RetrofitClient.instance.submitInventory(data)
                // 检查HTTP响应是否成功
                if (response.isSuccessful) {
                    // 如果响应体存在且code为200，则调用成功回调
                    response.body()?.let {
                        if (it.code == 200) {
                            onSuccess()
                        } else {
                            // 否则调用错误回调并传递错误信息
                            onError(it.message ?: "Unknown error")
                        }
                    }
                } else {
                    // 如果HTTP响应不成功，则调用错误回调并传递HTTP错误代码
                    onError("HTTP Error: ${response.code()}")
                }
            } catch (e: Exception) {
                // 捕获异常并记录日志，之后调用错误回调并传递异常本地化信息
                Log.e(TAG, "Submit failed", e)
                onError("Network error: ${e.localizedMessage}")
            }
        }
    }
}